@@ -17,10 +17,10 @@
 
 #define H2CORE_VERSION_MAJOR 1
 #define H2CORE_VERSION_MINOR 2
-#define H2CORE_VERSION_PATCH 3
+#define H2CORE_VERSION_PATCH 4
 
 #define H2CORE_GIT_REVISION 
-#define H2CORE_VERSION "1.2.3-"
+#define H2CORE_VERSION "1.2.4-"
 #define H2CORE_IS_DEVEL_BUILD true
 
 
@@ -50,6 +50,15 @@
 #ifndef H2CORE_HAVE_LIBSNDFILE
 #define H2CORE_HAVE_LIBSNDFILE
 #endif
+#ifndef H2CORE_HAVE_FLAC_SUPPORT
+#define H2CORE_HAVE_FLAC_SUPPORT
+#endif
+#ifndef H2CORE_HAVE_OPUS_SUPPORT
+#define H2CORE_HAVE_OPUS_SUPPORT
+#endif
+#ifndef H2CORE_HAVE_MP3_SUPPORT
+#define H2CORE_HAVE_MP3_SUPPORT
+#endif
 #ifndef H2CORE_HAVE_LIBARCHIVE
 #define H2CORE_HAVE_LIBARCHIVE
 #endif
@@ -92,5 +101,8 @@
 #ifndef H2CORE_HAVE_RUBBERBAND
 /* #undef H2CORE_HAVE_RUBBERBAND */
 #endif
+#ifndef HAVE_INTEGRATION_TESTS
+/* #undef HAVE_INTEGRATION_TESTS */
+#endif
 
 #endif
