@@ -32,6 +32,7 @@
 #include <core/Synth/Synth.h>
 #include <core/Basics/Note.h>
 #include <core/CoreActionController.h>
+#include <core/Preferences/Preferences.h>
 
 #include <core/IO/AudioOutput.h>
 #include <core/IO/JackAudioDriver.h>
@@ -46,6 +47,7 @@
 #include <chrono>
 #include <deque>
 #include <queue>
+#include <QString>
 
 /** \def RIGHT_HERE
  * Macro intended to be used for the logging of the locking of the
@@ -247,7 +249,8 @@ public:
 	 * Assert that the calling thread is the current holder of the
 	 * AudioEngine lock.
 	 */
-	void			assertLocked( );
+	void			assertLocked( const QString& sClass, const char* sFunction,
+								  const QString& sMsg );
 	void			noteOn( Note *note );
 
 	/**
@@ -291,15 +294,14 @@ public:
 	 * trigger their initialization.
 	 *
 	 * For a listing of all possible choices, please see
-	 * Preferences::m_sAudioDriver.
+	 * #H2Core::Preferences::AudioDriver.
 	 *
-	 * \param sDriver String specifying which audio driver should be
-	 * created.
+	 * \param driver Specific audio driver.
 	 * \return Pointer to the freshly created audio driver. If the
 	 * creation resulted in a NullDriver, the corresponding object will be
 	 * deleted and a null pointer returned instead.
 	 */
-	AudioOutput*	createAudioDriver( const QString& sDriver );
+	AudioOutput*	createAudioDriver( const Preferences::AudioDriver& driver );
 					
 	void			restartAudioDrivers();
 					
@@ -436,8 +438,8 @@ public:
 	 */
 	int getEnqueuedNotesNumber() const;
 
-	const QStringList getSupportedAudioDrivers() const;
-	
+	bool			isEndOfSongReached( std::shared_ptr<TransportPosition> pPos ) const;
+
 	/** Formatted string version for debugging purposes.
 	 * \param sPrefix String prefix which will be added in front of
 	 * every new line
@@ -468,9 +470,9 @@ public:
 	friend bool CoreActionController::activateLoopMode( bool );
 	/** Is allowed to set m_state to State::Ready via setState()*/
 	friend int FakeDriver::connect();
-	friend void JackAudioDriver::updateTransportPosition();
-	friend void JackAudioDriver::relocateUsingBBT();
+
 	friend class AudioEngineTests;
+		friend class JackAudioDriver;
 private:
 
 	/**
@@ -540,7 +542,6 @@ private:
 	 */
 	void			locateToFrame( const long long nFrame );
 	void			incrementTransportPosition( uint32_t nFrames );
-	bool			isEndOfSongReached( std::shared_ptr<TransportPosition> pPos ) const;
 	void			updateTransportPosition( double fTick, long long nFrame,
 											 std::shared_ptr<TransportPosition> pPos );
 	void			updateSongTransportPosition( double fTick, long long nFrame,
@@ -592,6 +593,8 @@ private:
 	 */
 	void handleSongModeChanged();
 
+	QString getDriverNames() const;
+
 	Sampler* 			m_pSampler;
 	Synth* 				m_pSynth;
 	AudioOutput *		m_pAudioDriver;
@@ -692,25 +695,16 @@ private:
 	double m_fLastTickEnd;
 	bool m_bLookaheadApplied;
 
-	/**
-	 * Attempts to dynamically load the JACK 2 shared library
-	 * and stores the result in #m_bJackSupported.
-	 */
-	void checkJackSupport();
-
-	/**
-	 * Whether or not the shared library of the JACK server could be
-	 * found on the system at runtime.
-	 */
-	bool m_bJackSupported;
-
-	QStringList m_supportedAudioDrivers;
-
 	/** Indicates how many loops the transport already did when the user presses
 	 * the Loop button again. */
 	int m_nLoopsDone;
 };
 
+#ifdef H2CORE_HAVE_DEBUG
+  #define ASSERT_AUDIO_ENGINE_LOCKED(x) assertAudioEngineLocked( _class_name(), __FUNCTION__, QString( "%1" ).arg( x ) );
+#else
+  #define ASSERT_AUDIO_ENGINE_LOCKED(x)
+#endif
 
 /**
  * AudioEngineLocking
@@ -734,7 +728,9 @@ protected:
 	/**
 	 *  Assert that the AudioEngine lock is held if needed.
 	 */
-	void assertAudioEngineLocked() const;
+	void assertAudioEngineLocked( const QString& sClass,
+								  const char* sFunction,
+								  const QString& sMsg ) const;
 
 
 public:
@@ -753,13 +749,6 @@ public:
 	}
 };
 
-
-inline void AudioEngine::assertLocked( ) {
-#ifndef NDEBUG
-	assert( m_LockingThread == std::this_thread::get_id() );
-#endif
-}
-
 inline void	AudioEngine::setMasterPeak_L( float value ) {
 	m_fMasterPeak_L = value;
 }
@@ -830,9 +819,6 @@ inline std::shared_ptr<Instrument> AudioEngine::getMetronomeInstrument() const {
 inline int AudioEngine::getEnqueuedNotesNumber() const {
 	return m_songNoteQueue.size();
 }
-inline const QStringList AudioEngine::getSupportedAudioDrivers() const {
-	return m_supportedAudioDrivers;
-}
 };
 
 #endif
