@@ -311,6 +311,12 @@ class Instrument : public H2Core::Object<Instrument>
 	/** Whether the instrument contains at least one non-missing
 	 * sample */
 	bool hasSamples() const;
+
+		/** Maximum support pitch value */
+		static constexpr float fPitchMax = 24.5;
+		/** Minimum support pitch value */
+		static constexpr float fPitchMin = -24.5;
+
 		/** Formatted string version for debugging purposes.
 		 * \param sPrefix String prefix which will be added in front of
 		 * every new line
@@ -572,11 +578,6 @@ inline void Instrument::set_random_pitch_factor( float val )
 	__random_pitch_factor = val;
 }
 
-inline void Instrument::set_pitch_offset( float val )
-{
-	__pitch_offset = val;
-}
-
 inline float Instrument::get_random_pitch_factor() const
 {
 	return __random_pitch_factor;
