@@ -26,6 +26,8 @@
 #include <core/Object.h>
 #include <QtCore/QString>
 
+#include <vector>
+
 namespace H2Core
 {
 
@@ -84,6 +86,32 @@ namespace H2Core
 			SessionReadWrite = 3
 		};
 
+			/** All audio file formats supported by Hydrogen */
+			enum class AudioFormat {
+				/** synonym for Aiff */
+				Aif,
+				/** synonym for Aiff */
+				Aifc,
+				Aiff,
+				Au,
+				Caf,
+				Flac,
+				Mp3,
+				Ogg,
+				Opus,
+				Unknown,
+				Voc,
+				W64,
+				Wav
+			};
+			/** Converts @a format to the default lower case suffix of the
+			 * format. */
+			static QString AudioFormatToSuffix( const AudioFormat& format );
+			/** Determines the audio format of the provided filename or path
+			 * based on its suffix. */
+			static AudioFormat AudioFormatFromSuffix( const QString& sFile );
+
+
 		static const QString songs_ext;
 		static const QString scripts_ext;
 		static const QString patterns_ext;
@@ -98,10 +126,18 @@ namespace H2Core
 
 		/**
 		 * check user and system filesystem usability
+		 *
+		 * If either @a sSysDataPath, @a sLogFile, or @a sUserConfigFile are not
+		 * provided or empty, the corresponding default values will be used
+		 *
 		 * \param logger is a pointer to the logger instance which will be used
-		 * \param sys_path an alternate system data path
+		 * \param sSysDataPath path to an alternate system data folder
+		 * \param sUserConfigFile path to an alternate hydrogen.conf config file
+		 * \param sLogFile path to alternate log file
 		 */
-		static bool bootstrap( Logger* logger, const QString& sys_path=nullptr );
+		static bool bootstrap( Logger* logger, const QString& sSysDataPath = "",
+							   const QString& sUserConfigFile = "",
+							   const QString& sLogFile = "" );
 
 		/** returns system data path */
 		static QString sys_data_path();
@@ -113,7 +149,9 @@ namespace H2Core
 
 		/** returns system config path */
 		static QString sys_config_path();
-		/** returns user config path */
+		/** @return user config path. This is either
+		 * $HOME/.hydrogen/hydrogen.conf or the alternative path provided via
+		 * CLI (see #m_sPreferencesOverwritePath) */
 		static QString usr_config_path();
 		/** returns system empty sample file path */
 		static QString empty_sample_path();
@@ -484,6 +522,15 @@ namespace H2Core
 		 */
 		static QString rerouteDrumkitPath( const QString& sDrumkitPath );
 
+			/** Removes all characters not within the Latin-1 range of @a
+			 * sEncodedString. */
+			static QString removeUtf8Characters( const QString& sEncodedString );
+
+			/** Which format is supported is determined by the `libsndfile`
+			 * version Hydrogen is linked against during compile time (see
+			 * https://libsndfile.github.io/libsndfile/api.html#open). */
+			 static const std::vector<AudioFormat>& supportedAudioFormats();
+
 	private:
 		static Logger* __logger;                    ///< a pointer to the logger
 		static bool check_sys_paths();              ///< returns true if the system path is consistent
@@ -535,6 +582,7 @@ namespace H2Core
 		static QString __usr_cfg_path;      ///< the path to the user config file
 		static QString __usr_log_path;      ///< the path to the log file
 		static QStringList __ladspa_paths;  ///< paths to laspa plugins
+			static std::vector<AudioFormat> m_supportedAudioFormats;
 	};
 
 	inline const QString& Filesystem::getPreferencesOverwritePath() {
