@@ -254,6 +254,9 @@ class OscServer : public H2Core::Object<OscServer>
 		 */
 		void handleAction(std::shared_ptr<Action> pAction);
 
+		/** Should be only used within the integration tests! */
+	lo::ServerThread* getServerThread() const;
+
 		/**
 		 * Creates an Action of type @b PLAY and passes its
 		 * references to MidiActionManager::handleAction().
@@ -488,6 +491,7 @@ class OscServer : public H2Core::Object<OscServer>
 		 * \param i Unused number of arguments passed by the OSC
 		 * message.*/
 		static void SELECT_AND_PLAY_PATTERN_Handler(lo_arg **argv, int i);
+		static void INSTRUMENT_PITCH_Handler( lo_arg **argv, int t);
 		/**
 		 * Creates an Action of type @b FILTER_CUTOFF_LEVEL_ABSOLUTE
 		 * and passes its references to
@@ -677,13 +681,13 @@ class OscServer : public H2Core::Object<OscServer>
 		 * message.*/
 		static void JACK_TRANSPORT_ACTIVATION_Handler(lo_arg **argv, int argc);
 		/**
-		 * Triggers CoreActionController::activateJackTimebaseMaster().
+		 * Triggers CoreActionController::activateJackTimebaseControl().
 		 *
-		 * \param argv The "f" field does contain the value supplied
-		 * by the user. If it is 0, the Jack timebase master will be
-		 * deactivated. Else, it will be activated instead.
+		 * \param argv The "f" field does contain the value supplied by the
+		 *   user. If it is `0`, Hydrogen will drop JACK Timebase control. Else,
+		 *   it tries to register as Timebase controller instead.
 		 * \param argc Unused number of arguments passed by the OSC
-		 * message.*/
+		 *   message.*/
 		static void JACK_TIMEBASE_MASTER_ACTIVATION_Handler(lo_arg **argv, int argc);
 		/**
 		 * Triggers CoreActionController::activateSongMode().
@@ -743,6 +747,49 @@ class OscServer : public H2Core::Object<OscServer>
 		 * \param argc Number of arguments passed by the OSC message.
 		 */
 		static void REMOVE_PATTERN_Handler(lo_arg **argv, int argc);
+		static void CLEAR_SELECTED_INSTRUMENT_Handler(lo_arg **argv, int argc);
+		/**
+		 * The handler expects the user to provide the number of the instrument
+		 * for which all notes should be removed from the currently selected
+		 * pattern.
+		 *
+		 * \param argv The "f" field does contain the instrument number
+		 * (caution: it starts at 0).
+		 * \param argc Number of arguments passed by the OSC message.
+		 */
+		static void CLEAR_INSTRUMENT_Handler(lo_arg **argv, int argc);
+		/**
+		 * The handler removes all notes from the the currently selected
+		 * pattern.
+		 *
+		 * \param argv The "f" field does contain the instrument number
+		 * (caution: it starts at 0).
+		 * \param argc Number of arguments passed by the OSC message.
+		 */
+		static void CLEAR_PATTERN_Handler(lo_arg **argv, int argc);
+
+		/**
+		 * Provides a similar behavior as a NOTE_ON MIDI message.
+		 *
+		 * \param argv The first "f" holds the note. It is designed after the
+		 *   MIDI NOTE_ON handling and expects an integer between 36 and 127
+		 *   (inspired by the General MIDI standard).
+		 *   The second "f" field contains the velocity of the new note within
+		 *   the range of [0, 1.0]
+		 * \param argc Number of arguments passed by the OSC message.
+		 */
+		static void NOTE_ON_Handler(lo_arg **argv, int argc);
+
+		/**
+		 * Provides a similar behavior as a NOTE_OFF MIDI message.
+		 *
+		 * \param argv The "f" field holds the note. It is designed after the
+		 *   MIDI NOTE_ON handling and expects an integer between 36 and 127
+		 *   (inspired by the General MIDI standard).
+		 * \param argc Number of arguments passed by the OSC message.
+		 */
+		static void NOTE_OFF_Handler(lo_arg **argv, int argc);
+
 		/**
 		 * Triggers CoreActionController::songEditorToggleGridCell().
 		 *
@@ -883,6 +930,10 @@ class OscServer : public H2Core::Object<OscServer>
 		std::list<lo_address> m_pClientRegistry;
 };
 
+inline lo::ServerThread* OscServer::getServerThread() const {
+	return m_pServerThread;
+}
+
 #endif /* H2CORE_HAVE_OSC */
 
 #endif // OSC_SERVER_H
